@@ -41,6 +41,7 @@ class ThetaService(object):
         start_datetime = datetime.combine(date, datetime.min.time().replace(tzinfo=timezone.utc))
         # end_datetime = datetime.combine(date, datetime.min.time().replace(tzinfo=timezone.utc))
         end_datetime = datetime.combine(date, datetime.max.time().replace(tzinfo=timezone.utc))
+        #return self.get_block_range_for_timestamps(start_datetime.timestamp(), end_datetime.timestamp()) #original ethereum-etl
         latest_timestamp = self._graph.get_last_point().y
         return self.get_block_range_for_timestamps(start_datetime.timestamp(), min(latest_timestamp, end_datetime.timestamp()))
 
@@ -86,7 +87,9 @@ class BlockTimestampGraph(object):
 
     def get_first_point(self):
         # Ignore the genesis block as its timestamp is 0
-        return Point(1, 1581035055)
+        # return Point(1, 1581035055) # testnet
+        return Point(1, 1552676478) # mainnet
+        
 
     def get_last_point(self):
 #        return block_to_point(self._theta_provider.eth.getBlock('latest'))  
